package org.gnomekr.argosdoc.node;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.net.MalformedURLException;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;

import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.HttpMethod;
import org.apache.commons.httpclient.HttpStatus;
import org.apache.commons.httpclient.methods.GetMethod;

/**
 * HTTPDocumentNode.java
 * @author Xavier Cho
 * @version $Revision: 1.1 $ $Date: 2005/11/18 08:29:39 $
 */
public class HTTPDocumentNode extends DocumentNode {

    static final long serialVersionUID = 6979774296461241855L;

    private URL baseURL;

    public HTTPDocumentNode(URL baseURL) throws MalformedURLException,
            URISyntaxException {
        super(baseURL.toExternalForm());

        this.baseURL = baseURL;

        URI summary = baseURL.toURI().resolve(SUMMARY_FILE_NAME);
        setURL(summary.toURL());
    }

    public URL getBaseURL() {
        return baseURL;
    }

    /**
     * @see org.gnomekr.argosdoc.node.DocumentNode#toExternalForm()
     */
    @Override
    public String toExternalForm() {
        return getBaseURL().toExternalForm();
    }

    /**
     * @see org.gnomekr.argosdoc.node.DocumentNode#getTOCFileReader()
     */
    @Override
    public Reader getTOCFileReader() throws IOException {
        URI uri;

        try {
            uri = getURL().toURI().resolve(TOC_FILE_NAME);
        } catch (URISyntaxException e) {
            String msg = "Unable to parse the specified URL : " + getURL();
            throw new IOException(msg);
        }

        HttpClient client = new HttpClient();
        HttpMethod method = new GetMethod(uri.toString());

        if (client.executeMethod(method) == HttpStatus.SC_OK) {
            InputStream in = method.getResponseBodyAsStream();
            return new BufferedReader(new InputStreamReader(in));
        } else {
            String msg = "Unable to retrieve TOC file from the specified URL : "
                    + method.getResponseBodyAsString();
            throw new IOException(msg);
        }
    }

}
