package org.gnomekr.argosdoc.node;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.Reader;
import java.net.MalformedURLException;

import org.apache.commons.lang.NullArgumentException;

public class LocalFileDocumentNode extends DocumentNode {

    static final long serialVersionUID = 4104578247570117597L;

    private File directory;

    public LocalFileDocumentNode(File dir) throws MalformedURLException {
        super(dir.getPath());

        if (dir == null) {
            throw new NullArgumentException("dir");
        }

        this.directory = dir;

        File summary = new File(dir + File.separator + SUMMARY_FILE_NAME);

        setURL(summary.toURL());
    }

    public File getDirectory() {
        return directory;
    }

    /**
     * @see org.gnomekr.argosdoc.node.DocumentNode#toExternalForm()
     */
    @Override
    public String toExternalForm() {
        return getDirectory().getAbsolutePath();
    }

    //TODO Pull up this method to provide implementation independent validation.
    public static boolean isValidJavaDocDirectory(File dir) {
        if (dir != null) {
            File htmlFile = new File(dir.getAbsolutePath() + File.separator
                    + TOC_FILE_NAME);

            if (htmlFile.exists() && htmlFile.canRead()) {
                return true;
            }
        }

        return false;
    }

    /**
     * @see org.gnomekr.argosdoc.node.DocumentNode#getTOCFileReader()
     */
    @Override
    public Reader getTOCFileReader() throws FileNotFoundException {
        File file = new File(directory.getAbsolutePath() + File.separator
                + TOC_FILE_NAME);

        return new BufferedReader(new FileReader(file));
    }
}
