package org.gnomekr.argosdoc.node;

import java.io.File;
import java.io.IOException;
import java.io.Reader;
import java.net.MalformedURLException;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.List;
import java.util.StringTokenizer;

import org.gnomekr.argosdoc.parser.JavaDocParser;

/**
 * NodeFactory.java
 * @author Xavier Cho
 * @version $Revision: 1.1 $ $Date: 2005/11/18 08:29:39 $
 */
public class NodeFactory {

    public static DocumentNode createDocumentNode(String externalForm)
            throws IOException, URISyntaxException {
        if (externalForm.startsWith("http")) {
            return createDocumentNode(new URL(externalForm));
        } else {
            return createDocumentNode(new File(externalForm));
        }
    }

    public static DocumentNode createDocumentNode(File file) throws IOException {
        return findChildNodes(new LocalFileDocumentNode(file));
    }

    public static DocumentNode createDocumentNode(URL url) throws IOException,
            URISyntaxException {
        return findChildNodes(new HTTPDocumentNode(url));
    }

    private static DocumentNode findChildNodes(DocumentNode document)
            throws IOException {
        Reader reader = document.getTOCFileReader();

        List<String> elements = JavaDocParser.parseTOCFile(reader);
        for (String element : elements) {
            ElementNode node = document;

            StringTokenizer tokenizer = new StringTokenizer(element, ".");
            while (tokenizer.hasMoreTokens()) {
                String token = tokenizer.nextToken();
                ElementNode child = node.findChild(token);

                URL baseURL = node.getURL();
                URL url = null;

                //TODO
                if (child == null) {
                    try {
                        if (tokenizer.hasMoreTokens()
                                && token.equals(token.toLowerCase())) {
                            child = new ElementNode(token, NodeType.Package);
                            url = baseURL.toURI().resolve(
                                    token + "/package.html").toURL();
                        } else {
                            child = new ElementNode(token, NodeType.Class);
                            url = baseURL.toURI().resolve(token + ".html")
                                    .toURL();
                        }
                    } catch (MalformedURLException e) {
                        // TODO 자동 생성된 catch 블록
                        e.printStackTrace();
                    } catch (URISyntaxException e) {
                        // TODO 자동 생성된 catch 블록
                        e.printStackTrace();
                    }

                    if (url != null) {
                        child.setURL(url);
                    }

                    child.setParent(node);
                    node.addChildNode(child);
                }

                node = child;
            }
        }

        return document;
    }
}