package org.gnomekr.argosdoc.parser;

import java.io.File;
import java.io.IOException;
import java.io.Reader;
import java.util.ArrayList;
import java.util.List;

import au.id.jericho.lib.html.Attributes;
import au.id.jericho.lib.html.Source;
import au.id.jericho.lib.html.StartTag;
import au.id.jericho.lib.html.Util;

/**
 * JavaDocParser.java
 * @author Xavier Cho
 * @version $Revision: 1.6 $ $Date: 2005/11/18 08:29:39 $
 */
public class JavaDocParser {

    public static List<String> parseTOCFile(Reader reader) throws IOException {
        List<String> elements = null;

        try {
            Source source = new Source(Util.getString(reader));
            List tags = source.findAllStartTags("A");
            elements = new ArrayList<String>(tags.size());

            for (Object obj : tags) {
                StartTag tag = (StartTag) obj;
                Attributes attributes = tag.getAttributes();
                String path = attributes.getValue("href");

                elements.add(translatePathToFQN(path));
            }
        } finally {
            reader.close();
        }

        return elements;
    }

    public static String translatePathToFQN(String path) {
        String value = null;

        if (path != null) {
            value = path.replace('/', '.');
            if (value.toLowerCase().endsWith(".html")) {
                value = value.substring(0, value.length() - 5);
            }
        }

        return value;
    }

    public static String translateFQNToPath(String name) {
        String value = null;

        if (name != null) {
            value = name.replace('.', File.separatorChar) + ".html";
        }

        return value;
    }
}