package org.gnomekr.argosdoc.view;

import java.net.MalformedURLException;
import java.net.URL;

import org.apache.commons.lang.StringUtils;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.browser.Browser;
import org.eclipse.swt.browser.LocationEvent;
import org.eclipse.swt.browser.LocationListener;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.ISelectionListener;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.part.ViewPart;
import org.gnomekr.argosdoc.node.ElementNode;

/**
 * DocumentsTreeView.java
 * @author Xavier Cho
 * @version $Revision: 1.4 $ $Date: 2005/11/18 09:44:50 $
 */
public class DocumentBrowserView extends ViewPart {

    public static final String ID = "argosdoc.view.DocumentBrowserView";

    private Browser browser;

    /**
     * This is a callback that will allow us to create the viewer and initialize
     * it.
     */
    public void createPartControl(Composite parent) {
        parent.setLayout(new FillLayout());

        this.browser = new Browser(parent, SWT.NONE);

        browser.addLocationListener(new LocationListener() {

            public void changing(LocationEvent event) {
            }

            public void changed(LocationEvent event) {
                try {
                    URL url = new URL(event.location);

                    DocumentsTreeView view = (DocumentsTreeView) getViewSite()
                            .getPage().findView(DocumentsTreeView.ID);
                    if (view != null) {
                        view.selectNodeWithURL(url);
                    }
                } catch (MalformedURLException e) {
                    // TODO 자동 생성된 catch 블록
                    e.printStackTrace();
                }
            }
        });

        getViewSite().getPage().addSelectionListener(new ISelectionListener() {

            public void selectionChanged(
                    IWorkbenchPart part,
                    ISelection selection) {
                if (selection instanceof IStructuredSelection) {
                    Object value = ((IStructuredSelection) selection)
                            .getFirstElement();
                    if (value instanceof ElementNode) {
                        ElementNode node = (ElementNode) value;
                        String location = node.getURL().toExternalForm();

                        String previousLocation = browser.getUrl();
                        if (StringUtils.isNotBlank(previousLocation)) {
                            try {
                                URL url = new URL(previousLocation);
                                if (url.toExternalForm().equals(location)) {
                                    return;
                                }
                            } catch (MalformedURLException e) {
                                // TODO 자동 생성된 catch 블록
                                e.printStackTrace();
                            }
                        }

                        browser.setUrl(location);
                    }
                }
            }
        });
    }

    /**
     * Passing the focus request to the viewer's control.
     */
    public void setFocus() {
        browser.setFocus();
    }
}