package org.gnomekr.argosdoc.wizard;

import org.eclipse.jface.dialogs.IDialogPage;
import org.eclipse.jface.wizard.IWizardNode;
import org.eclipse.jface.wizard.WizardSelectionPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.gnomekr.argosdoc.view.DocumentsTreeView;

/**
 * The "New" wizard page allows setting the container for the new file as well
 * as the file name. The page will only accept file name without the extension
 * OR with the extension that matches the expected one (mpe).
 */

public class AddDocumentPageIntro extends WizardSelectionPage {

    private IWizardNode localWizardNode;
    private IWizardNode remoteWizardNode;

    public AddDocumentPageIntro(DocumentsTreeView view) {
        super("AddDocumentPageIntro");

        this.localWizardNode = new AddLocalDocumentWizardNode(view);
        this.remoteWizardNode = new AddRemoteDocumentWizardNode(view);

        setTitle("Add JavaDoc API Document");
        setDescription("Please select the source of the JavaDoc API document you want to add.");
    }

    /**
     * @see IDialogPage#createControl(Composite)
     */
    public void createControl(Composite parent) {
        Composite container = new Composite(parent, SWT.NULL);
        GridLayout layout = new GridLayout();
        container.setLayout(layout);
        layout.numColumns = 1;
        layout.verticalSpacing = 10;
        layout.marginLeft = 10;
        layout.marginTop = 15;

        Button buttonLocal = new Button(container, SWT.RADIO);
        buttonLocal.setText("From the local file system,");
        buttonLocal.setSelection(true);
        buttonLocal.addSelectionListener(new SelectionListener() {

            public void widgetSelected(SelectionEvent e) {
                setSelectedNode(localWizardNode);
            }

            public void widgetDefaultSelected(SelectionEvent e) {
            }
        });

        Button buttonRemote = new Button(container, SWT.RADIO);
        buttonRemote.setText("From a remote web site.");
        buttonRemote.addSelectionListener(new SelectionListener() {

            public void widgetSelected(SelectionEvent e) {
                setSelectedNode(remoteWizardNode);
            }

            public void widgetDefaultSelected(SelectionEvent e) {
            }
        });

        setControl(container);

        setSelectedNode(localWizardNode);
    }
}