package org.gnomekr.argosdoc.wizard;

import java.io.File;

import org.apache.commons.lang.StringUtils;
import org.eclipse.jface.dialogs.IDialogPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;
import org.gnomekr.argosdoc.node.LocalFileDocumentNode;

/**
 * AddLocalDocumentPage.java
 * @author Xavier Cho
 * @version $Revision: 1.2 $ $Date: 2005/11/18 08:29:39 $
 */
public class AddLocalDocumentPage extends WizardPage {

    private Text textFile;
    private File directory;

    /**
     * Constructor for SampleNewWizardPage.
     * 
     * @param pageName
     */
    public AddLocalDocumentPage() {
        super("AddLocalDocumentPage");

        setTitle("Add Local JavaDoc API Document");
        setDescription("Please select the directory where index.html textFile of the JavaDoc document resides.");
    }

    public File getJavaDocPath() {
        return directory;
    }

    /**
     * @see IDialogPage#createControl(Composite)
     */
    public void createControl(Composite parent) {
        Composite container = new Composite(parent, SWT.NULL);
        GridLayout layout = new GridLayout();
        container.setLayout(layout);
        layout.numColumns = 3;
        layout.verticalSpacing = 10;
        layout.marginLeft = 10;
        layout.marginTop = 15;

        Label label = new Label(container, SWT.NULL);
        label.setText("JavaDoc &Path:");

        this.textFile = new Text(container, SWT.BORDER | SWT.SINGLE);
        textFile.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
        textFile.addModifyListener(new ModifyListener() {

            public void modifyText(ModifyEvent e) {
                dialogChanged();
            }
        });

        Button button = new Button(container, SWT.PUSH);
        button.setText("&Browse...");
        button.setLayoutData(new GridData());
        button.addSelectionListener(new SelectionAdapter() {

            public void widgetSelected(SelectionEvent e) {
                handleBrowse();
            }
        });

        setControl(container);
        setPageComplete(false);
    }

    /**
     * Uses the standard container selection dialog to choose the new value for
     * the container field.
     */
    private void handleBrowse() {
        DirectoryDialog dialog = new DirectoryDialog(getShell(), SWT.OPEN);
        String path = dialog.open();
        if (path != null) {
            textFile.setText(path);
        }
    }

    private void dialogChanged() {
        String path = textFile.getText();

        this.directory = null;

        if (StringUtils.isBlank(path)) {
            setMessage(null);
            setPageComplete(false);
        } else {
            if (LocalFileDocumentNode.isValidJavaDocDirectory(new File(path))) {
                setMessage(null);
                setPageComplete(true);

                this.directory = new File(path);
            } else {
                        setMessage("The specified path is not a valid JavaDoc root directory.");
                setPageComplete(false);
            }
        }
    }
}