package org.gnomekr.argosdoc.wizard;

import java.io.File;
import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.gnomekr.argosdoc.node.DocumentNode;
import org.gnomekr.argosdoc.node.NodeFactory;
import org.gnomekr.argosdoc.view.DocumentsTreeView;

/**
 * AddDocumentWizard.java
 * @author Xavier Cho
 * @version $Revision: 1.2 $ $Date: 2005/11/18 08:29:39 $
 */
public class AddLocalDocumentWizard extends Wizard {

    private DocumentsTreeView view;
    private AddLocalDocumentPage page;

    /**
     * Constructor for AddLocalDocumentWizard.
     */
    public AddLocalDocumentWizard(DocumentsTreeView view) {
        this.view = view;
        setNeedsProgressMonitor(true);
    }

    /**
     * Adding the page to the wizard.
     */

    public void addPages() {
        page = new AddLocalDocumentPage();
        addPage(page);
    }

    /**
     * This method is called when 'Finish' button is pressed in
     * the wizard. We will create an operation and run it
     * using wizard as execution context.
     */
    public boolean performFinish() {
        IRunnableWithProgress operation = new IRunnableWithProgress() {

            public void run(IProgressMonitor monitor)
                    throws InvocationTargetException, InterruptedException {
                monitor.beginTask(
                        "Parsing JavaDoc document...",
                        IProgressMonitor.UNKNOWN);
                try {
                    File directory = page.getJavaDocPath();

                    final DocumentNode document = NodeFactory
                            .createDocumentNode(directory);

                    Display.getDefault().syncExec(new Runnable() {

                        public void run() {
                            view.addDocument(document);
                        }
                    });
                } catch (final Exception e) {
                    e.printStackTrace();
                    Display.getDefault().syncExec(new Runnable() {

                        public void run() {
                            String msg = "Unable to read the specified JavaDoc path \n"
                                    + e.getMessage();
                            Shell parent = Display.getDefault()
                                    .getActiveShell();
                            MessageDialog.openError(parent, "Error", msg);
                        }
                    });
                } finally {
                    monitor.done();
                }
            }
        };

        try {
            getContainer().run(true, true, operation);
        } catch (InvocationTargetException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (InterruptedException e) {
            return false;
        }

        return true;
    }
}