package org.gnomekr.argosdoc.wizard;

import java.net.MalformedURLException;
import java.net.URL;

import org.apache.commons.lang.StringUtils;
import org.eclipse.jface.dialogs.IDialogPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

/**
 * AddRemoteDocumentPage.java
 * @author Xavier Cho
 * @version $Revision: 1.1 $ $Date: 2005/11/11 14:33:05 $
 */
public class AddRemoteDocumentPage extends WizardPage {

    private Text textURL;
    private URL url;

    /**
     * Constructor for SampleNewWizardPage.
     * 
     * @param pageName
     */
    public AddRemoteDocumentPage() {
        super("AddRemoteDocumentPage");

        setTitle("Add Remote JavaDoc API Site");
        setDescription("Please enter the URL of the website that contains the JavaDoc API document to be added.");
    }

    public URL getJavaDocURL() {
        return url;
    }

    /**
     * @see IDialogPage#createControl(Composite)
     */
    public void createControl(Composite parent) {
        Composite container = new Composite(parent, SWT.NULL);
        GridLayout layout = new GridLayout();
        container.setLayout(layout);
        layout.numColumns = 2;
        layout.verticalSpacing = 10;
        layout.marginLeft = 10;
        layout.marginTop = 15;

        Label label = new Label(container, SWT.NULL);
        label.setText("JavaDoc &Path:");

        this.textURL = new Text(container, SWT.BORDER | SWT.SINGLE);
        textURL.setText("http://");
        textURL.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
        textURL.addModifyListener(new ModifyListener() {

            public void modifyText(ModifyEvent e) {
                dialogChanged();
            }
        });

        setControl(container);
        setPageComplete(false);
    }

    private void dialogChanged() {
        String value = textURL.getText();

        this.url = null;

        if (StringUtils.isBlank(value)) {
            setMessage(null);
            setPageComplete(false);
        } else {
            try {
                this.url = new URL(value);

                setMessage(null);
                setPageComplete(true);
            } catch (MalformedURLException e) {
                setMessage("The specified URL is not a valid JavaDoc website.");
                setPageComplete(false);
            }
        }
    }
}