package org.gnomekr.apibrowser.parser;

import java.io.File;

import junit.framework.TestCase;

import org.gnomekr.argosdoc.node.DocumentNode;
import org.gnomekr.argosdoc.node.ElementNode;
import org.gnomekr.argosdoc.node.NodeFactory;
import org.gnomekr.argosdoc.parser.JavaDocParser;

public class JavaDocParserTest extends TestCase {

    private File dir;

    /**
     * @see junit.framework.TestCase#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        super.setUp();

        StringBuffer buffer = new StringBuffer();
        buffer.append(System.getProperty("user.dir"));
        buffer.append(File.separator);
        buffer.append("test");

        dir = new File(buffer.toString());
    }

    /**
     * @see junit.framework.TestCase#tearDown()
     */
    @Override
    protected void tearDown() throws Exception {
        super.tearDown();
        this.dir = null;
    }

    public void testTranslatePathToFQN() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("org");
        buffer.append(File.separator);
        buffer.append("gnomekr");
        buffer.append(File.separator);
        buffer.append("argosdoc");
        buffer.append(File.separator);
        buffer.append("APIBrowser.html");

        assertEquals("org.gnomekr.argosdoc.APIBrowser", JavaDocParser
                .translatePathToFQN(buffer.toString()));
    }

    public void testTranslateFQNToPath() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("org");
        buffer.append(File.separator);
        buffer.append("gnomekr");
        buffer.append(File.separator);
        buffer.append("argosdoc");
        buffer.append(File.separator);
        buffer.append("APIBrowser.html");

        assertEquals(buffer.toString(), JavaDocParser
                .translateFQNToPath("org.gnomekr.argosdoc.APIBrowser"));
    }

    /**
     * 'org.gnomekr.argosdoc.parser.JavaDocParser.parseDocument(File)' 테스트 메소드
     */
    public void testParseDocument() throws Exception {
        DocumentNode document = NodeFactory.createDocumentNode(dir);

        assertNotNull(document);
        assertFalse(document.isLeaf());
        assertEquals(1, document.getChildCount());

        ElementNode node = document.getChildren()[0];
        assertEquals("org", node.getName());

        assertFalse(node.isLeaf());
        assertEquals(1, node.getChildCount());

        node = node.getChildren()[0];
        assertEquals("eclipse", node.getName());

        assertFalse(node.isLeaf());
        assertEquals(1, node.getChildCount());

        node = node.getChildren()[0];
        assertEquals("emf", node.getName());

        assertFalse(node.isLeaf());
        assertEquals(7, node.getChildCount());
    }
}
